@@ -1100,18 +1100,20 @@ bool ChannelStream::getStatus(Channel *ch,ChanPacket &pack)
 		hit.initLocal(numListeners,numRelays,ch->info.numSkips,ch->info.getUptime(),isPlaying, oldp, newp);
 		hit.tracker = ch->isBroadcasting();
 
-		if ((numRelays) && ((servMgr->getFirewall() == ServMgr::FW_OFF) && (servMgr->autoRelayKeep!=0))) { //JP-EX
-			ch->stayConnected = true;
-			LOG_DEBUG("Channel Auto keeped");
-		} else
-    		LOG_DEBUG("Channel numRelays: %d, FW: %s, autoKeep: %d",
-    			 numRelays + numListeners, (servMgr->getFirewall() == ServMgr::FW_OFF) ? "OFF" : "ON",
-    			 servMgr->autoRelayKeep);
-    		  
-		if ((!numRelays && !numListeners) && (servMgr->autoRelayKeep==2)) { //JP-EX
-			ch->stayConnected = false;
-			LOG_DEBUG("Channel Disabled keep");
-		}
+                if (servMgr->getFirewall() == ServMgr::FW_OFF &&
+                    servMgr->autoRelayKeep == 1) {
+                        ch->stayConnected = true;
+                        LOG_DEBUG("Channel Auto keeped[1]");
+                } else if (servMgr->getFirewall() == ServMgr::FW_OFF &&
+                           servMgr->autoRelayKeep == 2 &&
+                           (numRelays || numListeners)) {
+                        ch->stayConnected = true;
+                        LOG_DEBUG("Channel Auto keeped[2]");
+                } else if ((!numRelays && !numListeners) &&
+                           (servMgr->autoRelayKeep == 2)) {
+                        ch->stayConnected = false;
+                        LOG_DEBUG("Channel Disabled keep[2]: no relay and listener.");
+                }
 
 		MemoryStream pmem(pack.data,sizeof(pack.data));
 		AtomStream atom(pmem);
