@@ -578,7 +578,7 @@ void Servent::handshakeIn()
 
     while (http.nextHeader())
     {
-		LOG_DEBUG(http.cmdLine);
+		LOG_DEBUG("%s",http.cmdLine);
 
 		char *arg = http.getArgStr();
 		if (!arg)
@@ -1887,6 +1887,9 @@ void Servent::processIncomingPCP(bool suggestOthers)
 					int cnt = servMgr->broadcastPushRequest(best,rhost,noID,Servent::T_CIN);
 					LOG_DEBUG("Broadcasted tracker push request to %d clients for %s",cnt,rstr);
 				}
+			}else
+			{
+				LOG_DEBUG("No available trackers");
 			}
 		}
 
