@@ -44,6 +44,8 @@ char *nextCGIarg(char *cp, char *cmd, char *arg)
 	if (!*cp)
 		return NULL;
 
+	int cnt=0;
+
 	// fetch command
 	while (*cp)
 	{
@@ -52,9 +54,14 @@ char *nextCGIarg(char *cp, char *cmd, char *arg)
 			break;
 		else
 			*cmd++ = c;
+
+		cnt++;
+		if (cnt >= (MAX_CGI_LEN-1))
+			break;
 	}
 	*cmd = 0;
 
+	cnt=0;
 	// fetch arg
 	while (*cp)
 	{
@@ -63,6 +70,10 @@ char *nextCGIarg(char *cp, char *cmd, char *arg)
 			break;
 		else
 			*arg++ = c;
+
+		cnt++;
+		if (cnt >= (MAX_CGI_LEN-1))
+			break;
 	}
 	*arg = 0;
 
@@ -158,20 +169,23 @@ void Servent::handshakeHTTP(HTTP &http, bool isHTTP)
 					   (c->info.contentType == ChanInfo::T_MP3) )
 					{
 						// if we have a mount point then check for it, otherwise update all channels.
-						if (mountArg)
-						{
-							if (strcmp(c->mount,mountArg)==0)
-							{
-								ChanInfo newInfo = c->info;
-								newInfo.track.title.set(songArg,String::T_ESC);
-								newInfo.track.title.convertTo(String::T_UNICODE);
 
-								if (urlArg)
-									if (urlArg[0])
-										newInfo.track.contact.set(urlArg,String::T_ESC);
-								LOG_CHANNEL("Channel Shoutcast update: %s",songArg);
-								c->updateInfo(newInfo);
-							}
+						bool match=true;
+
+						if (mountArg)
+							match = strcmp(c->mount,mountArg)==0;
+
+						if (match)
+						{
+							ChanInfo newInfo = c->info;
+							newInfo.track.title.set(songArg,String::T_ESC);
+							newInfo.track.title.convertTo(String::T_UNICODE);
+
+							if (urlArg)
+								if (urlArg[0])
+									newInfo.track.contact.set(urlArg,String::T_ESC);
+							LOG_CHANNEL("Channel Shoutcast update: %s",songArg);
+							c->updateInfo(newInfo);
 						}
 					}
 					c=c->next;
@@ -666,9 +680,9 @@ bool Servent::handshakeAuth(HTTP &http,const char *args,bool local)
 // -----------------------------------
 void Servent::handshakeCMD(char *cmd)
 {
-	char result[256];
-	char arg[1024]; //JP-EX 512->1024
-	char curr[256];
+	char result[MAX_CGI_LEN];
+	char arg[MAX_CGI_LEN]; //JP-EX 512->1024
+	char curr[MAX_CGI_LEN];
 
 	char	jumpStr[128];
 	char	*jumpArg=NULL;
@@ -1449,13 +1463,12 @@ void Servent::handshakeXML()
 		while (chl)
 		{
 			if (chl->isUsed())
-				if (!chl->info.isPrivate())
-					fn->add(createChannelXML(chl));
+				fn->add(createChannelXML(chl));
 			chl = chl->next;
 		}
 	}
 
-
+#if 0
 	if (servMgr->isRoot)
 	{
 		// add private channels
@@ -1473,7 +1486,7 @@ void Servent::handshakeXML()
 			}
 		}
 	}
-
+#endif
 
 	XML::Node *hc = new XML::Node("host_cache");
 	for(i=0; i<ServMgr::MAX_HOSTCACHE; i++)
