@@ -58,7 +58,7 @@ ServMgr::ServMgr()
 	lastIncoming = 0;
 
 	maxBitrateOut = 540; //JP-Patch 0-> 540
-	maxRelays = 1;
+	maxRelays = MIN_RELAYS;
 	maxDirect = 0;
 	refreshHTML = 5;
 
@@ -1582,8 +1582,8 @@ Servent *ServMgr::findConnection(Servent::TYPE t,GnuID &sid)
 // --------------------------------------------------
 void ServMgr::procConnectArgs(char *str,ChanInfo &info)
 {
-	char arg[512];
-	char curr[256];
+	char arg[MAX_CGI_LEN];
+	char curr[MAX_CGI_LEN];
 
 	char *args = strstr(str,"?");
 	if (args)
@@ -1644,9 +1644,22 @@ void ServMgr::procConnectArgs(char *str,ChanInfo &info)
 bool ServMgr::start()
 {
 	char idStr[64];
+
+
+	const char *priv;
+#if PRIVATE_BROADCASTER
+	priv = "(private)";
+#else
+	priv = "";
+#endif
+	LOG_DEBUG("Peercast %s, %s %s",PCX_VERSTRING,peercastApp->getClientTypeOS(),priv);
+
 	sessionID.toStr(idStr);
 	LOG_DEBUG("SessionID: %s",idStr);
 
+	chanMgr->broadcastID.toStr(idStr);
+	LOG_DEBUG("BroadcastID: %s",idStr);
+
 	checkForceIP();
 
 
@@ -2015,8 +2028,8 @@ int ServMgr::serverProc(ThreadInfo *thread)
 // -----------------------------------
 void	ServMgr::setMaxRelays(int max)
 {
-	if (max <= 0)
-		max = 1;
+	if (max < MIN_RELAYS)
+		max = MIN_RELAYS;
 	maxRelays = max;
 }
 
