@@ -8,22 +8,18 @@
 /* misc */
 gboolean gp_quit_app (GtkWidget *, gpointer);
 void log_clear_cb (GtkWidget *, gpointer);
+void log_scroll_toggled (GtkWidget *, gpointer);
 
 /* Menu */
-void menu_about_cb (GtkMenuItem *, GnomePeercastApp *);
-void menu_pref_cb (GtkToolButton *, GnomePeercastApp *);
-void menu_quit_cb (GtkMenuItem *, GnomePeercastApp *);
-void menu_web_cb (GtkMenuItem *, GnomePeercastApp *);
-void menu_yp_cb (GtkMenuItem *, GnomePeercastApp *);
-void menu_new_cb (GtkMenuItem *, GnomePeercastApp *);
+void menu_about_cb (GtkMenuItem *, gpointer);
+void menu_pref_cb (GtkToolButton *, gpointer);
+void menu_quit_cb (GtkMenuItem *, gpointer);
+void menu_web_cb (GtkMenuItem *, gpointer);
+void menu_yp_cb (GtkMenuItem *, gpointer);
+void menu_new_cb (GtkMenuItem *, gpointer);
 
 /* Channel List */
 void chan_selection_changed_cb (GtkTreeSelection *, gpointer);
-void chan_stop_cb (GtkWidget *, ChannelList *);
-void chan_bump_cb (GtkWidget *, ChannelList *);
-void chan_url_cb (GtkWidget *, ChannelList *);
-void chan_info_cb (GtkWidget *, ChannelList *);
-void chan_play_cb (GtkWidget *, ChannelList *);
 
 /* Channel List popup menu */
 void chan_play_stream_url_cb (GtkWidget *, ChannelList *);
