@@ -390,15 +390,24 @@ GnomePeercastApp::guiInit (void)
 void APICALL
 GnomePeercastApp::printLog(LogBuffer::TYPE t, const char *str)
 {
-	loglock.on();
-	if (gui)
-		logview->appendLog (t, str);
+	gchar * logstr;
+	GError *e = NULL;
+	GThread *thread;
+	LogString *ls;
+
+	ls = new LogString(t, str);
+	
+	if (gui) {
+		thread = g_thread_create((GThreadFunc)&logview->appendLog_s,
+					 ls, FALSE, &e);
+		/* LogString will be deleted into appendLog_s thread */
+		//logview->appendLog (t, str);
+	}
 	else {
 		if (t != LogBuffer::T_NONE)
 			g_print ("[%s] ", LogBuffer::getTypeStr(t));
 		g_print ("%s\n",str);
 	}
-	loglock.off();
 }
 
 gint
