@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* chaninfo-dialog.cpp
  *
- * Copyright (C) 2005 Takuo KITAME.
+ * Copyright (C) 2006 Takuo KITAME.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -39,7 +39,7 @@ scroll_idle_cb (gpointer data)
 
 	gtk_text_buffer_get_end_iter (buffer, &iter);
 	gtk_text_view_scroll_to_iter (tv, &iter, 0, FALSE, 0, 0);	
-	
+
         return FALSE;
 }
 
@@ -65,6 +65,7 @@ LogView::scrollToEnd (void)
 	gtk_widget_show (GTK_WIDGET (textview));
 }
 
+
 void
 LogView::appendLog (LogBuffer::TYPE type, const gchar *str)
 {
@@ -78,7 +79,7 @@ LogView::appendLog (LogBuffer::TYPE type, const gchar *str)
 	GtkTextIter iter;
 
 	line++;
-
+	
 	t = sys->getTime();
 	lt = localtime ((const time_t *)&t);
 	strftime (timestr, sizeof(timestr), "%m/%d %H:%M:%S", lt);
@@ -102,6 +103,51 @@ LogView::appendLog (LogBuffer::TYPE type, const gchar *str)
 	}
 }
 
+void
+LogView::appendLog_s (gpointer data)
+{
+	LogString *ls = (LogString *)data;
+	struct tm * lt;
+	time_t t;
+	gchar timestr[40];
+	static unsigned int line = 0;
+	GnomePeercastApp *app = (GnomePeercastApp *)peercastApp;
+	GtkWidget *w;
+	GtkTextBuffer *buffer;
+	GtkTextIter iter;
+	GtkTextView *tv = (GtkTextView *)app->getWidget("text_log");
+
+	gdk_threads_enter();
+	
+	line++;
+	
+	t = sys->getTime();
+	lt = localtime ((const time_t *)&t);
+	strftime (timestr, sizeof(timestr), "%m/%d %H:%M:%S", lt);
+
+	buffer = gtk_text_view_get_buffer (tv);
+	gtk_text_buffer_get_end_iter (buffer, &iter);
+	gtk_text_buffer_insert (buffer, &iter, timestr, -1);
+	gtk_text_buffer_insert (buffer, &iter, " [", -1);
+	gtk_text_buffer_insert_with_tags_by_name (buffer, &iter,
+						  LogBuffer::getTypeStr(ls->type),
+						  -1,
+						  "bold", NULL);
+	gtk_text_buffer_insert (buffer, &iter, "] ", -1);
+	gtk_text_buffer_insert (buffer, &iter, ls->data, -1);
+	gtk_text_buffer_insert (buffer, &iter, "\n", -1);
+
+	delete ls;
+	
+	w = app->getWidget ("log_scroll");
+	
+	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (w))) {
+		gtk_text_buffer_get_end_iter (buffer, &iter);
+		gtk_text_view_scroll_to_iter (tv, &iter, 0, FALSE, 0, 0);
+	}
+	gdk_threads_leave();
+}
+
 void
 LogView::clearLog (void)
 {
@@ -111,3 +157,8 @@ LogView::clearLog (void)
 	gtk_text_buffer_set_text (buffer, "", -1);
 }
 
+LogString::LogString(LogBuffer::TYPE t, const char *str)
+{
+	data = g_strdup(str);
+	type = t;
+}
