@@ -7,6 +7,18 @@
 #include <gnome.h>
 #include "utils.h"
 
+
+class LogString
+{
+public:
+    LogString (LogBuffer::TYPE, const char *);
+    ~LogString (void) {
+        g_free(data);
+    }
+    LogBuffer::TYPE type;
+    char *data;
+};
+
 class LogView
 {
 public:
@@ -18,6 +30,7 @@ public:
 
     void scrollToEnd (void);
     void appendLog (LogBuffer::TYPE, const gchar *);
+    static void appendLog_s (gpointer);
     void clearLog (void);
     void init (GtkWidget *);
 
@@ -26,4 +39,7 @@ private:
     gint scroll_src;
 };
 
+
+
+
 #endif
