@@ -169,13 +169,15 @@ main (gint argc, gchar* argv[])
 
 	peercastApp = (PeercastApplication *)myapp;
 	peercastInst->init();
-
 	myapp->gconfInit ();
 	myapp->infoInit ();
 
 	handle_cmdline_args (argc, argv);
 
+	gdk_threads_init();
+	gdk_threads_enter();
 	gtk_main();
+	gdk_threads_leave();
 
 	/* clean up */
 	peercastInst->saveSettings ();
