@@ -301,6 +301,12 @@ list_init (GtkTreeView *tv)
 			    CAT_ID, 9,
 			    CAT_NAME, _("GUI"),
 			    -1);
+
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter,
+			    CAT_ID, 10,
+			    CAT_NAME, _("Applications"),
+			    -1);
 }
 
 static void
@@ -444,11 +450,19 @@ auto_keep_toggled (GtkToggleButton *b, GtkWidget *child)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (child), FALSE);
 }
 
+static void
+use_gnome_browser_toggled (GtkToggleButton *b, GtkWidget *child)
+{
+	gtk_widget_set_sensitive (child, ! gtk_toggle_button_get_active (b));
+}
+
 void
 SettingDialog::setCurrent (void)
 {
 	GtkWidget *w;
 	gchar buf[1024];
+	gchar *c;
+	gchar *mstr;
 	GdkColor color;
 	GnomePeercastApp *ap = (GnomePeercastApp *)peercastApp;
 
@@ -630,22 +644,62 @@ SettingDialog::setCurrent (void)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				      ap->getConfigBool (CONF_GUI_PREFIX"/name_resolve_hitlist"));
 
-	gdk_color_parse (ap->getConfigString (CONF_GUI_PREFIX"/color_direct"), &color);
+	mstr = ap->getConfigString (CONF_GUI_PREFIX"/color_direct");
+	gdk_color_parse (mstr,  &color);
+	g_free (mstr);
 	w = getWidget ("gui_color_direct");
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &color);
 
-	gdk_color_parse (ap->getConfigString (CONF_GUI_PREFIX"/color_firewalled"), &color);
+	mstr = ap->getConfigString (CONF_GUI_PREFIX"/color_firewalled");
+	gdk_color_parse (mstr, &color);
+	g_free (mstr);
 	w = getWidget ("gui_color_firewalled");
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &color);
 
-	gdk_color_parse (ap->getConfigString (CONF_GUI_PREFIX"/color_unfirewalled"), &color);
+	mstr = ap->getConfigString (CONF_GUI_PREFIX"/color_unfirewalled");
+	gdk_color_parse (mstr, &color);
+	g_free (mstr);
 	w = getWidget ("gui_color_unfirewalled");
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &color);
 
-	gdk_color_parse (ap->getConfigString (CONF_GUI_PREFIX"/color_push_relay"), &color);
+	mstr = ap->getConfigString (CONF_GUI_PREFIX"/color_push_relay");
+	gdk_color_parse (mstr, &color);
+	g_free (mstr);
 	w = getWidget ("gui_color_push_relay");
 	gtk_color_button_set_color (GTK_COLOR_BUTTON (w), &color);
 
+	/* Applications */
+	w = getWidget ("app_entry_ogg");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_ogg");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+	w = getWidget ("app_entry_mp3");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_mp3");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+	w = getWidget ("app_entry_nsv");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_nsv");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+	w = getWidget ("app_entry_wma");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_wma");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+	w = getWidget ("app_entry_wmv");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_wmv");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+	w = getWidget ("app_entry_raw");
+	c = ap->getConfigString (CONF_GLOBAL_PREFIX"/app_raw");
+	gtk_entry_set_text (GTK_ENTRY (w), c);
+	g_free (c);
+
+	w = getWidget ("app_list_frame");
+	signalConnect ("app_chk_use_gnome_browser_toggled",
+		       G_CALLBACK (use_gnome_browser_toggled), w);
+	w = getWidget ("app_chk_use_gnome_browser");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+				      ap->getConfigBool (CONF_GLOBAL_PREFIX"/use_gnome_browser"));
 }
 
 void
@@ -818,19 +872,19 @@ SettingDialog::apply (void)
 	w = getWidget ("ext_chk_auto_keep");
 	servMgr->autoRelayKeep =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)) ? 1 : 0;
-	
+
 	w = getWidget ("ext_chk_auto_keep_opt");
 	servMgr->autoRelayKeep =
 		gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)) ? 2 : servMgr->autoRelayKeep;
-	
+
 	w = getWidget ("ext_spin_kick_fw_numrelays");
 	servMgr->kickPushStartRelays = 
 		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
-	
+
 	w = getWidget ("ext_spin_kick_fw_interval");
 	servMgr->kickPushInterval =
 		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
-	
+
 	w = getWidget ("ext_spin_auto_bump");
 	servMgr->autoBumpSkipCount =
 		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
@@ -845,7 +899,7 @@ SettingDialog::apply (void)
 	w = getWidget ("ext_spin_auto_max_relays");
 	servMgr->autoMaxRelaySetting =
 		gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (w));
-	
+
 
 	/* GUI */
 	w = getWidget ("gui_chk_resolve_connection");
@@ -880,6 +934,34 @@ SettingDialog::apply (void)
 	if ((servMgr->isRoot) && (brRoot))
 		servMgr->broadcastRootSettings(getUpdate);
 
+	/* Applications */
+	w = getWidget ("app_entry_ogg");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_ogg", (gchar *)str);
+
+	w = getWidget ("app_entry_mp3");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_mp3", (gchar *)str);
+
+	w = getWidget ("app_entry_nsv");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_nsv", (gchar *)str);
+
+	w = getWidget ("app_entry_wma");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_wma", (gchar *)str);
+
+	w = getWidget ("app_entry_wmv");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_wmv", (gchar *)str);
+
+	w = getWidget ("app_entry_raw");
+	str = gtk_entry_get_text (GTK_ENTRY (w));
+	ap->setConfigString (CONF_GLOBAL_PREFIX"/app_raw", (gchar *)str);
+
+	w = getWidget ("app_chk_use_gnome_browser");
+	ap->setConfigBool (CONF_GLOBAL_PREFIX"/use_gnome_browser",
+			   gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)));
 	ap->gconfInit ();
 }
 
@@ -894,6 +976,8 @@ SettingDialog::SettingDialog (GtkWindow *window)
 	GtkTreeIter iter;
 	GtkWidget *dialog;
 
+	debug_print (1, "New object: SettingDialog");
+
 	parent = window;
 
 	xml =load_glade_xml (GLADE_FILE_NAME, "setting_dlg");
@@ -933,3 +1017,4 @@ SettingDialog::SettingDialog (GtkWindow *window)
 				       G_CALLBACK (response_cb), this);
 	gtk_widget_show (dialog);
 }
+
